﻿using System;
using System.Collections.Generic;
using PizzaModel;
using System.Data.Objects;
// Data access object for pizza order information
// One of these is created for each transaction needing these calls
// Has state: the EDM context object for this transaction, set up in service layer
// Note no SaveChanges or transaction actions here--those are in the service layer
namespace PizzaDAO
{
    public class PizzaOrderDAO
    {
        private PizzaEntities context;

        // use a DAO for the lifetime of one context
        public PizzaOrderDAO(PizzaEntities ctx)
        {
            context = ctx;
        }
 
        public PizzaSize FindPizzaSizeByID(String sizeID)
        {
            ObjectQuery<PizzaSize> sizes = context.PizzaSize.Where("it.ID = " + sizeID);
            return sizes.First();  // or throw if none there
        }
        public PizzaSize FindPizzaSizeByName(String sizeName)
        {
            ObjectQuery<PizzaSize> sizes = context.PizzaSize.Where("it.SizeName = '" + sizeName + "'");
            if (sizes.Exists())
                return sizes.First();
            else return null;
        }

        public List<PizzaSize> FindAllPizzaSizes()
        {
            ObjectQuery<PizzaSize> realSizesQuery = context.PizzaSize.Where("it.SizeName is not null");
            List<PizzaSize> realSizes = new List<PizzaSize>();
            // make list of real sizes
            foreach (PizzaSize s in realSizesQuery)
                realSizes.Add(s);
            return realSizes;
        }

        public Topping FindToppingByName(String toppingName)
        {
            ObjectQuery<Topping> toppings = context.Topping.Where("it.ToppingName = '" + toppingName + "'");
            if (toppings.Exists())
                return toppings.First();
            else return null;
        }
        public Topping FindToppingByID(String toppingID)
        {
            ObjectQuery<Topping> toppings = context.Topping.Where("it.ID = " + toppingID);
            return toppings.First();  // or throw
        }

        public List<Topping> FindAllToppings()
        {
            ObjectQuery<Topping> realTopsQuery = context.Topping.Where("it.ToppingName is not null");
            List<Topping> realTops = new List<Topping>();
            // make list of real toppings
            foreach (Topping t in realTopsQuery)
                realTops.Add(t);
            return realTops;
        }
        public PizzaOrder InsertOrder(int roomNumber, PizzaSize size, List<Topping> toppings, int day, int status)
        {
            PizzaOrder order = new PizzaOrder();
            
            // add size to order--
            order.PizzaSize = size;
            // size.Order.Add(order);
            // add toppings to order--
            
            foreach (Topping t in toppings)
            {
                // t.Order.Add(order);
                order.Topping.Add(t);
            }
            order.Day = day;
            // order.PizzaSize = size;
            // order.Topping.Add(top);  // get error as 2nd addition to relationship
            order.RoomNumber = roomNumber;
            order.Status = status;
            context.AddObject("PizzaOrder", order);
            return order;
        }
        // find first order with specified status
        public PizzaOrder FindFirstOrder(int status)
        {
            ObjectQuery<PizzaOrder> orders = null;
            orders = context.PizzaOrder.Where("it.Status = " + status).OrderBy("it.ID").Top("1");
            return orders.First();
        }
        // Get orders, including toppings for a certain day and room number
        // and make sure they are pulled out of query within the Tx
        // by iterating through the query and placing them in a List
        public List<PizzaOrder> FindOrdersByRoom(int roomNumber, int day)
        {
            ObjectQuery<PizzaOrder> orders = null;
            orders = context.PizzaOrder.Where("it.roomNumber = " + roomNumber)
                                .Where("it.day = " + day)
                                .Include("Topping").Include("PizzaSize");
            List<PizzaOrder> orders1 = new List<PizzaOrder>();
            // make list of PizzaOrders, pulling domain objects out of query within Tx
            foreach (PizzaOrder o in orders)
                orders1.Add(o);

            return orders1;
        }
        // get all orders, without toppings, between day1 and day2 (inclusive)
        // The caller has to run the query here, by iterating through returned IEnumerable
        public IEnumerable<PizzaOrder> FindOrdersByDays(int day1, int day2)
        {
            ObjectQuery<PizzaOrder> orders = null;
            orders = context.PizzaOrder.Where("it.day >= " + day1)
                                .Where("it.day <= " + day2);
            return orders;
        }

    }
}
