SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

USE [master];
GO

IF EXISTS (SELECT * FROM sys.databases WHERE name = 'Pizza1')
	DROP DATABASE Pizza1;
GO

-- Create the Pizza database.
CREATE DATABASE Pizza1;
GO

USE Pizza1;
GO

-- Create the PizzaOrder table.
IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = 
	OBJECT_ID(N'[dbo].[PizzaOrder]') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[PizzaOrder](
	[ID] [int] IDENTITY(1,1) NOT NULL,
	[RoomNumber] [int] NOT NULL,
	[SizeID] [int] NOT NULL,
	[Day] [int] NOT NULL,
	[Status] [int] NOT NULL,
 CONSTRAINT [PK_Pizza.PizzaOrder] PRIMARY KEY CLUSTERED 
(
	[ID] ASC
) ON [PRIMARY]
) ON [PRIMARY]
END
GO

-- Create the PizzaSize table.
IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = 
	OBJECT_ID(N'[dbo].[PizzaSize]') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[PizzaSize](
	[ID] [int] IDENTITY(1,1) NOT NULL,
	[SizeName] [nvarchar](50) NOT NULL UNIQUE,
 CONSTRAINT [PK_Pizza.PizzaSize] PRIMARY KEY CLUSTERED 
(
	[ID] ASC
) ON [PRIMARY]
) ON [PRIMARY]
END
GO

-- Create the OrderTopping table.
IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = 
	OBJECT_ID(N'[dbo].[OrderTopping]') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[OrderTopping](
	[OrderID] [int] NOT NULL,
	[ToppingID] [int] NOT NULL,
 CONSTRAINT [PK_OrderTopping] PRIMARY KEY CLUSTERED 
(
	[ToppingID] ASC, [OrderID] ASC
) ON [PRIMARY]
) ON [PRIMARY]
END
GO
-- Create the Topping table.
IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[Topping]') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[Topping](
	[ID] [int] IDENTITY(1,1) NOT NULL,
	[ToppingName] [nvarchar](50) NOT NULL UNIQUE,
 CONSTRAINT [PK_Topping] PRIMARY KEY CLUSTERED 
(
	[ID] ASC
) ON [PRIMARY]
) ON [PRIMARY]
END
GO
-- Create the SysTime table.
IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[SysTime]') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[SysTime](
	[ID] [int] IDENTITY(1,1) NOT NULL,
	[CurrentDay] [int] NOT NULL,
	[LastReportDay] [int] NOT NULL,
 CONSTRAINT [PK_SysTime] PRIMARY KEY CLUSTERED 
(
	[ID] ASC
) ON [PRIMARY]
) ON [PRIMARY]
END
GO

-- Define the relationship between PizzaOrder and PizzaSize
IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[FK_PizzaOrder_PizzaSize]') AND type = 'F')
ALTER TABLE [dbo].[PizzaOrder]  WITH CHECK ADD  CONSTRAINT [FK_PizzaOrder_PizzaSize] FOREIGN KEY([ID])
REFERENCES [dbo].[PizzaSize] ([ID])
GO

ALTER TABLE [dbo].[PizzaOrder] CHECK CONSTRAINT [FK_PizzaOrder_PizzaSize]
GO
-- Define the relationship between OrderTopping and Topping
IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[FK_OrderTopping_Topping]') AND type = 'F')
ALTER TABLE [dbo].[OrderTopping]  WITH CHECK ADD  CONSTRAINT [FK_OrderTopping_Topping] FOREIGN KEY([ToppingID])
REFERENCES [dbo].[Topping] ([ID])
GO

ALTER TABLE [dbo].[OrderTopping] CHECK CONSTRAINT [FK_OrderTopping_Topping]
GO

-- Define the relationship between OrderTopping and PizzaOrder
IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[FK_OrderTopping_PizzaOrder]') AND type = 'F')
ALTER TABLE [dbo].[OrderTopping]  WITH CHECK ADD  CONSTRAINT [FK_OrderTopping_PizzaOrder] FOREIGN KEY([OrderID])
REFERENCES [dbo].[PizzaOrder] ([ID])
GO

ALTER TABLE [dbo].[OrderTopping] CHECK CONSTRAINT [FK_OrderTopping_PizzaOrder]
GO

SET IDENTITY_INSERT dbo.SysTime ON
GO
INSERT INTO [SysTime] (ID, CurrentDay, LastReportDay) VALUES (1,1,0);
GO
SET IDENTITY_INSERT dbo.SysTime OFF
GO

SET ANSI_NULLS ON
GO
SET QUOTED_IDENTIFIER ON
GO

USE [master];
GO

IF EXISTS (SELECT * FROM sys.databases WHERE name = 'Pizza1')
	DROP DATABASE Pizza1;
GO

-- Create the Pizza database.
CREATE DATABASE Pizza1;
GO

USE Pizza1;
GO

-- Create the PizzaOrder table.
IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = 
	OBJECT_ID(N'[dbo].[PizzaOrder]') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[PizzaOrder](
	[PizzaOrderID] [int] IDENTITY(1,1) NOT NULL,
	[RoomNumber] [int] NOT NULL,
	[PizzaSizeID] [int] NOT NULL,
	[Day] [int] NOT NULL,
	[Status] [int] NOT NULL,
 CONSTRAINT [PK_Pizza.PizzaOrder] PRIMARY KEY CLUSTERED 
(
	[PizzaOrderID] ASC
) ON [PRIMARY]
) ON [PRIMARY]
END
GO

-- Create the PizzaSize table.
IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = 
	OBJECT_ID(N'[dbo].[PizzaSize]') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[PizzaSize](
	[PizzaSizeID] [int] IDENTITY(1,1) NOT NULL,
	[SizeName] [nvarchar](50) NOT NULL UNIQUE,
 CONSTRAINT [PK_Pizza.PizzaSize] PRIMARY KEY CLUSTERED 
(
	[PizzaSizeID] ASC
) ON [PRIMARY]
) ON [PRIMARY]
END
GO

-- Create the OrderTopping table.
IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = 
	OBJECT_ID(N'[dbo].[OrderTopping]') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[OrderTopping](
	[ToppingID] [int] NOT NULL,
	[OrderID] [int] NOT NULL,
 CONSTRAINT [PK_OrderTopping] PRIMARY KEY CLUSTERED 
(
	[ToppingID] ASC, [OrderID] ASC
) ON [PRIMARY]
) ON [PRIMARY]
END
GO
-- Create the Topping table.
IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[Topping]') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[Topping](
	[ToppingID] [int] IDENTITY(1,1) NOT NULL,
	[ToppingName] [nvarchar](50) NOT NULL UNIQUE,
 CONSTRAINT [PK_Topping] PRIMARY KEY CLUSTERED 
(
	[ToppingID] ASC
) ON [PRIMARY]
) ON [PRIMARY]
END
GO
-- Create the SysTime table.
IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[SysTime]') AND OBJECTPROPERTY(id, N'IsUserTable') = 1)
BEGIN
CREATE TABLE [dbo].[SysTime](
	[SysTimeID] [int] IDENTITY(1,1) NOT NULL,
	[CurrentDay] [int] NOT NULL,
	[LastReportDay] [int] NOT NULL,
 CONSTRAINT [PK_SysTime] PRIMARY KEY CLUSTERED 
(
	[SysTimeID] ASC
) ON [PRIMARY]
) ON [PRIMARY]
END
GO

-- Define the relationship between PizzaOrder and PizzaSize
IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[FK_PizzaOrder_PizzaSize]') AND type = 'F')
ALTER TABLE [dbo].[PizzaOrder]  WITH CHECK ADD  CONSTRAINT [FK_PizzaOrder_PizzaSize] FOREIGN KEY([PizzaSizeID])
REFERENCES [dbo].[PizzaSize] ([PizzaSizeID])
GO

ALTER TABLE [dbo].[PizzaOrder] CHECK CONSTRAINT [FK_PizzaOrder_PizzaSize]
GO
-- Define the relationship between OrderTopping and Topping
IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[FK_OrderTopping_Topping]') AND type = 'F')
ALTER TABLE [dbo].[OrderTopping]  WITH CHECK ADD  CONSTRAINT [FK_OrderTopping_Topping] FOREIGN KEY([ToppingID])
REFERENCES [dbo].[Topping] ([ToppingID])
GO

ALTER TABLE [dbo].[OrderTopping] CHECK CONSTRAINT [FK_OrderTopping_Topping]
GO

-- Define the relationship between OrderTopping and PizzaOrder
IF NOT EXISTS (SELECT * FROM dbo.sysobjects WHERE id = OBJECT_ID(N'[dbo].[FK_OrderTopping_PizzaOrder]') AND type = 'F')
ALTER TABLE [dbo].[OrderTopping]  WITH CHECK ADD  CONSTRAINT [FK_OrderTopping_PizzaOrder] FOREIGN KEY([OrderID])
REFERENCES [dbo].[PizzaOrder] ([PizzaOrderID])
GO

ALTER TABLE [dbo].[OrderTopping] CHECK CONSTRAINT [FK_OrderTopping_PizzaOrder]
GO

SET IDENTITY_INSERT dbo.SysTime ON
GO
INSERT INTO [SysTime] (SysTimeID, CurrentDay, LastReportDay) VALUES (1,1,0);
GO
SET IDENTITY_INSERT dbo.SysTime OFF
GO

